Add A New Add-on Center To Your Plone Site
##########################################

I assume you want to add the center to the Plone site root ('Home'). Therefor go to this site root and
choose from the Plone menu on the left 'Add new'. You get in this menu an entry to create a new
'Add-on Center' (see the screenshot below).

.. image:: images/create_addon_center.png
   :width: 600


Click on this entry and you get the form below. This is the edit form to create and configure a new
Add-on Center in your Plone site.

.. image:: images/addon_center_form01.png
   :width: 600


Fill in the fields in the edit form of the Add-on Center. All fields has a description of their expected values.
Don't miss to go through the register of the edit form dialog.

The first register 'Default' (screenshot above) contains the fields for setting title of the add-on center, to
describe the features of the add-ons and the naming of the add-on. If older product versions are removed from
the listing, there is a field for the text to show next to the search feature of the center, how to search for
add-ons compatible with this older product versions.

The second register ('Instructions') (see screenshot below) provides two fields to give information to the user, how to install the
add-on and how to report bugs.

.. image:: images/addon_center_form02.png
   :width: 600


Within the third register (see screenshot below) it is possible to set special email addresses. The first field could be used to
send an email to an address once a new release has been published. The second field holds the address for
the communication with the manager or the add-on reviewer on the site.

.. image:: images/addon_center_form03.png
   :width: 600

Once you are finished with adding values to the edit form, save the form. If you missed to edit a form field,
you will get an error message and could fill in the necessary information into the appropriate form field.

Publish The New Add-on Center
*****************************

Once you finished with the edit form of the Add-on Center and saved your changes you need to publish the center.
You could do this by a click on the entry 'State: Private' in the menubar on the left site. Choose the entry 'Publish'
and you are done.

Sharing: Enable Members To Add Projects
***************************************

The logged in users are not able to add projects to the Add-on Center yet. You could enable this by a mouse click
on the entry 'Sharing' in menubar on the left site (see screenshot below). This shows the edit menu for sharing
and you could tick the checkbox 'Can add' for 'logged-in-users' (see screenshot below) to enable the members of the Plone site to add their add-on projects to the center.

.. image:: images/addon_center_sharing.png
   :width: 600

